pub fn byte_decode<const d: usize, const PACK_LEN: usize>(
B: &[u8; PACK_LEN],
) -> PolynomialExpand description
Algorithm 6 ByteDecode_d(𝐵) Decodes a byte array into an array of 𝑑-bit integers for 1 ≤ 𝑑 ≤ 12. Input: byte array 𝐵 ∈ 𝔹32𝑑 . Output: integer array 𝐹 ∈ ℤ256 , where 𝑚 = 2𝑑 if 𝑑 < 12 and 𝑚 = 𝑞 if 𝑑 = 12. Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.