pub fn sample_ntt(rho: &[u8; 32], nonce: &[u8; 2]) -> PolynomialExpand description
Algorithm 7 SampleNTT(𝐵) Takes a 32-byte seed and two indices as input and outputs a pseudorandom element of 𝑇𝑞. Input: byte array 𝐵 ∈ 𝔹34 . ▷ a 32-byte seed along with two indices Output: array 𝑎_hat ∈ ℤ256 ▷ the coefficients of the NTT of a polynomial Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.