sample_poly_cbd

Function sample_poly_cbd 

pub fn sample_poly_cbd<const eta: i16>(bytes: &[u8]) -> Polynomial
Algorithm 8 SamplePolyCBD (𝐵)𝜂 Takes a seed as input and outputs a pseudorandom sample from the distribution D𝜂(𝑅𝑞). Input: byte array 𝐵 ∈ 𝔹64𝜂. Output: array 𝑓 ∈ ℤ256 ▷ the coefficients of the sampled polynomial Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.